@@ -79,8 +79,9 @@ void BackgroundWindow::emergencyShow()
     show();
 }
 
-AbstractLocker::AbstractLocker() :
-    m_background(new BackgroundWindow(this))
+AbstractLocker::AbstractLocker(QObject *parent)
+    : QObject(parent)
+    , m_background(new BackgroundWindow(this))
 {
 }
 
@@ -99,4 +100,3 @@ void AbstractLocker::addAllowedWindow(quint32 windows)
 
 }
 
-#include "abstractlocker.moc"
